## Running PCA

## Programs that implement PCA: Eigenstrat (https://github.com/DReichLab/EIG/tree/master/EIGENSTRAT), KING (http://people.virginia.edu/~wc9c/KING/), R, and many, many, many others.
## Additional reading:
## •	Price, A. L., Patterson, N. J., Plenge, R. M., Weinblatt, M. E., Shadick, N. A., & Reich, D. (2006). Principal components analysis corrects for stratification in genome-wide association studies. Nature genetics, 38(8), 904.
## •	Novembre, J., Johnson, T., Bryc, K., Kutalik, Z., Boyko, A. R., Auton, A., ... & Stephens, M. (2008). Genes mirror geography within Europe. Nature, 456(7218), 98.
## •	McVean, G. (2009). A genealogical interpretation of principal components analysis. PLoS genetics, 5(10), e1000686.

## Running it in R (bold-underlined statements are R commands you can use)
## Steps
## 1)	Open R
## 2)	Type ?prcomp to learn about this function and how to use it
?prcomp

## 3)	Let’s read in some data
## a.	Use data=read.table(“”) with the name of the file in the quotes
## b.	One example is 
setwd("<your directory>")
#setwd("~/Dropbox/Research/Presentations/2023/07_SISG/Day2_PM2/Day2_PM_2_SimDat_1") #this is my directory
for(i in 0:9){
  cat("SimDat.A0.",i,".rdat\n",sep="")

  data=read.table(paste("SimDat.A0.",i,".rdat",sep=""))
  ## c.	The first column are population labels so let’s pull them out and give them their own data structure: 
  labels = data[,1]
  data=data[,2:length(data[1,])]
  ## d.	Let’s get ready some colors. I use which, “which” probably isn’t the best way but it works
  col=rep("black",length(labels))
  col[which(labels=="P2")] = "red"
  col[which(labels=="P4")] = "blue"
  col[which(labels=="A3")] = "purple"
  col[which(labels=="A5")] = "orange"

  ## 4)	Run prcomp
  ## a.	You will need the “x” output so specify retx (“return x”), though it is in the default as well
  ## b.	Centering and scaling are also suggested.
  ## c.	So that leaves us with:
  pca = prcomp(data,center=TRUE,retx=TRUE,scale.=TRUE)
  ## 5)	So what do you have?
  ##   a.	What is x?
  ##   b.	If you plot x what do you see?
  plot(x=pca$x[,1],y=pca$x[,2],col=col,pch=19)
  ## c.	How much variation does each PC explain?
  ## i.	sdev is the square root of the eigenvalues for each PC. When we divide the absolute value of each eigenvalue by the sum of all the values we get the proportion of variance that the PC explains.
  pca$sdev[1]**2/sum(pca$sdev**2)
}
barplot(pca$sdev[1:10]**2/sum(pca$sdev**2)) ##for the first 10 PCs (beyond that it gets difficult to look at)

## iv.	This is a scree plot
## v.	Which PCs explain most of the variation?
## vi.	Which don’t seem to add much?
## 6)	What do you think the “A” in the file names stands for?
## a.	Run the other data sets and see how they differ.
