########################################################################
########################################################################
### STEPs to run LEA for population structure analysis

### 1) Installation
########################################################################
########################################################################
# - 1.1 Install the following packages
install.packages(c("fields","RColorBrewer","mapplots"))

# - 1.2 Installing LEA package depending on R version (These comand lines have to be run just in the first time you will use the package)
####### 
#-----------------------------------------------------------------------
### For R version 3.4 or older 
source("http://bioconductor.org/biocLite.R")
biocLite("LEA")

#-----------------------------------------------------------------------
### For R version 3.5 or greater

if (!require("BiocManager", quietly = TRUE))
  install.packages("BiocManager")

BiocManager::install("LEA")

#-----------------------------------------------------------------------
### Other option

source("http://bioconductor.org/biocLite.R")
install.packages("LEA_1.4.0_tar.gz", repos = NULL, type ="source")

#-----------------------------------------------------------------------
###   Other Important libraries

source("http://membres-timc.imag.fr/Olivier.Francois/Conversion.R")
source("http://membres-timc.imag.fr/Olivier.Francois/POPSutilities.R")

########################################################################
########################################################################
## 2) Running population STRUCTURE
########################################################################
########################################################################

library(LEA)

## 1) Creating LEA input, depending on your input file format, you can create the input using:

## For PLINK format (PED files)
## The following two lines will create a file with geno extension on the same directory of your input file with the same prefix
#### Please change the <type your file name> to the path and file name in your computer.
#### If you are working in the same folder of the script you just have to include the file name.
#### Example in linux: "/home/victor/UMB/SISG/2022/4Pops.LDpruned0.1.ped"
#### setwd("~/Dropbox/Research/Presentations/2023/07_SISG/Day2_PM2/Population_structure_analysis_LEA/") #my location

setwd(<YOUR_DIRECTORY>)
input.file<- "4Pops.LDpruned0.1.ped" 
genotype=ped2geno(input.file)

## Use this in case you are working with VCF format
input.file<- <type your file name> 
genotype=vcf2geno(input.file)

########################################################################
##  We run the program using the snmf function for several K, for example from 2 to 4, corresponding to the number of ancestral populations.
##  The output will be an object of class “snmf” on R and also it will create a folder on the input directory.
##  This folder includes subfolders for each K value, and each K folder includes Q (admixture proportions) and G (allelic frequencies for each ancestral populations for each variant) files 
##  This object includes the values of the cross-entropy criterion by K and the ancestry proportions

obj.snmf = snmf(genotype, K = 1:5, entropy = T, ploidy = 2, project="new")

## Since the program was called with the entropy option, we can plot the values of the cross-entropy criterion for each K
plot(obj.snmf)

## Depending on which K value have the minimum value for cross-entropy criterion, you can visualize this results as a barplot of ancestry coeffcients.
barplot(t(Q(obj.snmf, K = 2)), col = c("red","blue"))
barplot(t(Q(obj.snmf, K = 3)), col = c("red","blue","gold"))
barplot(t(Q(obj.snmf, K = 4)), col = c("red","green","blue","gold"))
barplot(t(Q(obj.snmf, K = 5)), col = c("red","green","blue","gold","grey"))

